@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 import datetime
 import struct
@@ -42,12 +42,14 @@ def packet_summary(pkt):
 
 class DataOut(object):
     def __init__(self, terminal_serial,
+                 terminal_client_id=None,
                  terminal_type=None,
                  src_ip=None, dst_ip=None,
                  tcp_sport=None, tcp_dport=None,
                  src_mac=None, dst_mac=None,
                  pkt_time=None):
         self.terminal_serial = terminal_serial
+        self.terminal_client_id = terminal_client_id
         self.terminal_type = terminal_type
         self.src_ip = src_ip
         self.dst_ip = dst_ip
@@ -59,6 +61,7 @@ class DataOut(object):
 
     def __dict__(self):
         return dict(terminal_serial=self.terminal_serial,
+                    terminal_client_id=self.terminal_client_id,
                     terminal_type=self.terminal_type,
                     src_ip=self.src_ip,
                     dst_ip=self.dst_ip,
@@ -74,14 +77,16 @@ class DataOut(object):
 
 def get_json_serial(packet):
     serial = None
+    clientId = None
     try:
         raw_json_data = struct.unpack_from(">256s", bytes(packet), offset=54)[0].decode('utf8')
         json_data = json.loads(raw_json_data)
         serial = json_data[0].get("terminalSerial")
+        clientid = json_data[0].get("clientId")
     except Exception as e:
         logging.debug(e)
-        return None
-    return serial
+        return None, None
+    return serial, clientid
 
 def get_vt10_serial(packet):
     serial = None
@@ -146,7 +151,7 @@ def parse_file(args):
         t_serial = get_teltonika_serial(packet)
         r_serial = get_ruptela_serial(packet)
         v_serial = get_vt10_serial(packet)
-        j_serial = get_json_serial(packet)
+        j_serial, terminal_client_id = get_json_serial(packet)
 
         if t_serial:
             terminal_type = "Teltonika"
@@ -167,6 +172,7 @@ def parse_file(args):
             continue
 
         payload = DataOut(serial,
+                          terminal_client_id,
                           terminal_type,
                           *packet_summ
                           )
